@@ -849,7 +849,7 @@ main (int argc, char** argv)
             }
         }
 
-        for (int i=0; i<attrs.size(); i++)
+        for (size_t i=0; i<attrs.size(); i++)
             delete attrs[i].attr;
     }
     catch (const exception& e)
